Struct Board

pub struct Board { /* private fields */ }
A Tic Tac Toe board

Implementations

Source

impl Board

pub fn new() -> Self

Make a new Board.

pub fn get_turn(self) -> Team

Get the team whos turn it is.

pub fn is_draw(self) -> bool

Returns true if it is a draw.

This does not check for wins.

pub fn has_won(self, team: Team) -> bool

Check if the given team won.

This is designed to be fast.

pub fn get_winner(self) -> Option<Team>

Get the winner if they exist

pub fn get_winner_info(self) -> Option<WinnerInfo>

Get the winner info, if there is a winner

This is much slower than Self::get_winner.

pub fn set(self, index: u8, team: Option<Team>) -> Self

Set the tile at the index.

Panics

Panics if the index >= 9.

pub fn get(self, index: u8) -> Option<Team>

Get the tile at the index.

Panics

Panics if the index >= 9.

pub fn iter_children(self) -> ChildrenIter

Get an iterator over child board states.

Returns

Returns an Iterator where Items are tuples. The first item is the index of the placed tile. The second is the resulting board state.

pub fn iter(self) -> impl Iterator<Item = (u8, Option<Team>)>

Get an iterator over the tiles.

The iterator starts at 0 at the top left and ends at 8 at the bottom right.

Returns

Returns a tuple pair, where the first element is the index and the second is the tile value.

pub fn encode_u16(self) -> u16

Encode this board as a u16.

pub fn decode_u16(data: u16) -> Self

Decode a u16 into a board